diff --git a/Ninjacrab.PersistentWindows.Solution/SystrayShell/Program.cs b/Ninjacrab.PersistentWindows.Solution/SystrayShell/Program.cs
index 826508e..b6cf80b 100644
--- a/Ninjacrab.PersistentWindows.Solution/SystrayShell/Program.cs
+++ b/Ninjacrab.PersistentWindows.Solution/SystrayShell/Program.cs
@@ -251,7 +251,7 @@ namespace PersistentWindows.SystrayShell
icon_path2 = Path.Combine(appDataFolder, "pwIconBusy.png");
if (File.Exists(icon_path2))
{
- var bitmap = new System.Drawing.Bitmap(icon_path2); // or get it from resource
+ var bitmap = new System.Drawing.Bitmap(icon_path2);
var iconHandle = bitmap.GetHicon();
BusyIcon = System.Drawing.Icon.FromHandle(iconHandle);
}
@@ -260,8 +260,9 @@ namespace PersistentWindows.SystrayShell
BusyIcon = new System.Drawing.Icon(icon_path);
}
else
- {
- BusyIcon = Properties.Resources.pwIconBusy;
+ {
+ var iconHandle = Properties.Resources.pwIconBusy.GetHicon();
+ BusyIcon = System.Drawing.Icon.FromHandle(iconHandle);
}
systrayForm = new SystrayForm();
diff --git a/Ninjacrab.PersistentWindows.Solution/SystrayShell/Properties/Resources.resx b/Ninjacrab.PersistentWindows.Solution/SystrayShell/Properties/Resources.resx
index e1ca5a0..854b34f 100644
--- a/Ninjacrab.PersistentWindows.Solution/SystrayShell/Properties/Resources.resx
+++ b/Ninjacrab.PersistentWindows.Solution/SystrayShell/Properties/Resources.resx
@@ -122,7 +122,10 @@
..\Resources\pwIcon.ico;System.Drawing.Icon, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
- ..\Resources\pwIconBusy.ico;System.Drawing.Icon, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
+ ..\Resources\pwIconBusy.png;System.Drawing.Bitmap, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
+
+
+ ..\Resources\pwIconUpdate.png;System.Drawing.Bitmap, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
..\Resources\question.png;System.Drawing.Bitmap, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
diff --git a/Ninjacrab.PersistentWindows.Solution/SystrayShell/Resources/pwIconBusy.ico b/Ninjacrab.PersistentWindows.Solution/SystrayShell/Resources/pwIconBusy.ico
deleted file mode 100644
index 8670185..0000000
Binary files a/Ninjacrab.PersistentWindows.Solution/SystrayShell/Resources/pwIconBusy.ico and /dev/null differ
diff --git a/Ninjacrab.PersistentWindows.Solution/SystrayShell/Resources/pwIconBusy.png b/Ninjacrab.PersistentWindows.Solution/SystrayShell/Resources/pwIconBusy.png
new file mode 100644
index 0000000..2e02d2d
Binary files /dev/null and b/Ninjacrab.PersistentWindows.Solution/SystrayShell/Resources/pwIconBusy.png differ
diff --git a/Ninjacrab.PersistentWindows.Solution/SystrayShell/Resources/pwIconUpdate.png b/Ninjacrab.PersistentWindows.Solution/SystrayShell/Resources/pwIconUpdate.png
new file mode 100644
index 0000000..50b35c6
Binary files /dev/null and b/Ninjacrab.PersistentWindows.Solution/SystrayShell/Resources/pwIconUpdate.png differ
diff --git a/Ninjacrab.PersistentWindows.Solution/SystrayShell/SystrayShell.csproj b/Ninjacrab.PersistentWindows.Solution/SystrayShell/SystrayShell.csproj
index 1d5be4b..ac4ca25 100644
--- a/Ninjacrab.PersistentWindows.Solution/SystrayShell/SystrayShell.csproj
+++ b/Ninjacrab.PersistentWindows.Solution/SystrayShell/SystrayShell.csproj
@@ -123,6 +123,12 @@
false
+
+
+
+
+
+
copy $(SolutionDir)*.bat $(TargetDir)
diff --git a/Ninjacrab.PersistentWindows.Solution/SystrayShell/Properties/Resources.Designer.cs b/Ninjacrab.PersistentWindows.Solution/SystrayShell/Properties/Resources.Designer.cs
index a8508bd..88d1563 100644
--- a/Ninjacrab.PersistentWindows.Solution/SystrayShell/Properties/Resources.Designer.cs
+++ b/Ninjacrab.PersistentWindows.Solution/SystrayShell/Properties/Resources.Designer.cs
@@ -71,12 +71,22 @@ namespace PersistentWindows.SystrayShell.Properties {
}
///
/// Looks up a localized resource of type System.Drawing.Icon similar to (Icon).
///
- internal static System.Drawing.Icon pwIconBusy {
+ internal static System.Drawing.Bitmap pwIconBusy {
get {
object obj = ResourceManager.GetObject("pwIconBusy", resourceCulture);
- return ((System.Drawing.Icon)(obj));
+ return ((System.Drawing.Bitmap)(obj));
+ }
+ }
+
+ ///
+ /// Looks up a localized resource of type System.Drawing.Bitmap.
+ ///
+ internal static System.Drawing.Bitmap pwIconUpdate {
+ get {
+ object obj = ResourceManager.GetObject("pwIconUpdate", resourceCulture);
+ return ((System.Drawing.Bitmap)(obj));
}
}
@@ -71,12 +71,22 @@ namespace PersistentWindows.SystrayShell.Properties {
}
///
- /// Looks up a localized resource of type System.Drawing.Icon similar to (Icon).
+ /// Looks up a localized resource of type System.Drawing.Bitmap.
///